@@ -94,4 +94,8 @@ class PageNewConfig (Page, FormHelper):
         self._cfg['server!bind!1!port']            = "1234"
         self._cfg['vserver!1!rule!5!handler!type'] = "normal"
 
+        self._cfg['source!2!type'] = "host"
+        self._cfg['source!2!nick'] = "localhost 8000"
+        self._cfg['source!2!host'] = "localhost:8000"
+
         self._cfg.save()
