@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2008 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2009 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- */
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */ 
 
 /* IN CASE THIS PLUG-IN IS COMPILED WITH OPENSSL:
  *
@@ -71,7 +71,6 @@ typedef struct {
 
 typedef struct {
 	cherokee_cryptor_vserver_t  base;
-	cherokee_avl_r_t            session_cache;
 	SSL_CTX                    *context;
 } cherokee_cryptor_vserver_libssl_t;
 
