@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2006 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2009 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- */
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */ 
 
 #if !defined (CHEROKEE_INSIDE_CHEROKEE_H) && !defined (CHEROKEE_COMPILATION)
 # error "Only <cherokee/cherokee.h> can be included directly, this file may disappear or change contents."
@@ -45,8 +45,10 @@ typedef ret_t (* encoder_func_init_t)        (void  *encoder);
 typedef ret_t (* encoder_func_encode_t)      (void  *encoder, cherokee_buffer_t *in, cherokee_buffer_t *out);
 typedef ret_t (* encoder_func_flush_t)       (void  *encoder, cherokee_buffer_t *in, cherokee_buffer_t *out);
 
+/* Data types
+ */
 typedef struct {
-	cherokee_module_t module;
+	cherokee_module_t          module;
 
 	/* Pure virtual methods
 	 */
@@ -56,15 +58,39 @@ typedef struct {
 	
 	/* Properties
 	 */
-	void *conn;
-
+	void                      *conn;
 } cherokee_encoder_t;
 
 #define ENCODER(x)      ((cherokee_encoder_t *)(x))
 #define ENCODER_CONN(x) (CONN(ENCODER(x)->conn))
 
-ret_t cherokee_encoder_init_base   (cherokee_encoder_t *enc);
 
+/* Easy initialization
+ */
+#define ENCODER_CONF_PROTOTYPE(name)                                \
+	ret_t cherokee_encoder_ ## name ## _configure (             \
+		cherokee_config_node_t   *,                         \
+		cherokee_server_t        *,                         \
+	 	cherokee_module_props_t **)
+
+#define PLUGIN_INFO_ENCODER_EASY_INIT(name)                         \
+	ENCODER_CONF_PROTOTYPE(name);                               \
+                                                                    \
+	PLUGIN_INFO_INIT(name, cherokee_encoder,                    \
+		(void *)cherokee_encoder_ ## name ## _new,          \
+		(void *)NULL)
+
+#define PLUGIN_INFO_ENCODER_EASIEST_INIT(name)                      \
+	PLUGIN_EMPTY_INIT_FUNCTION(name)                            \
+	PLUGIN_INFO_ENCODER_EASY_INIT(name)
+
+
+/* Methods
+ */
+ret_t cherokee_encoder_init_base   (cherokee_encoder_t *enc, cherokee_plugin_info_t *info);
+
+/* Encoder virtual methods
+ */
 ret_t cherokee_encoder_free        (cherokee_encoder_t *enc);
 ret_t cherokee_encoder_add_headers (cherokee_encoder_t *enc, cherokee_buffer_t *buf);
 ret_t cherokee_encoder_init        (cherokee_encoder_t *enc, void *conn);
