@@ -118,8 +118,9 @@ cherokee_handler_proxy_configure (cherokee_config_node_t   *conf,
 		cherokee_module_props_init_base (MODULE_PROPS(n), 
 						 MODULE_PROPS_FREE(props_free));
 
-		n->balancer  = NULL;
-		n->reuse_max = DEFAULT_REUSE_MAX;
+		n->balancer           = NULL;
+		n->reuse_max          = DEFAULT_REUSE_MAX;
+		n->in_allow_keepalive = true;
 
 		INIT_LIST_HEAD (&n->in_request_regexs);
 		INIT_LIST_HEAD (&n->in_headers_add);
@@ -151,6 +152,9 @@ cherokee_handler_proxy_configure (cherokee_config_node_t   *conf,
 		} else if (equal_buf_str (&subconf->key, "reuse_max")) {
 			props->reuse_max = atoi (subconf->val.buf);
 
+		} else if (equal_buf_str (&subconf->key, "in_allow_keepalive")) {
+			props->in_allow_keepalive = !! atoi (subconf->val.buf);
+
 		} else if (equal_buf_str (&subconf->key, "in_header_hide")) {
 			cherokee_config_node_foreach (j, subconf) {
 				cherokee_avl_add (&props->in_headers_hide, 
@@ -248,6 +252,7 @@ static ret_t
 add_request (cherokee_handler_proxy_t *hdl,
 	     cherokee_buffer_t        *buf)
 {
+	int                             re;
 	ret_t                           ret;
 	cherokee_connection_t          *conn  = HANDLER_CONN(hdl);
 	cherokee_buffer_t              *tmp   = &HANDLER_THREAD(hdl)->tmp_buf1;
@@ -257,14 +262,16 @@ add_request (cherokee_handler_proxy_t *hdl,
 
 	/* Build the URL
 	 */
-	ret = cherokee_buffer_add_buffer (tmp, &conn->request);
+	ret = cherokee_buffer_escape_uri (tmp, &conn->request);
 	if (ret != ret_ok) {
 		return ret_error;
 	}
 
-	ret = cherokee_buffer_add_buffer (tmp, &conn->pathinfo);
-	if (ret != ret_ok) {
-		return ret_error;
+	if (! cherokee_buffer_is_empty (&conn->pathinfo)) {
+		ret = cherokee_buffer_escape_uri (tmp, &conn->pathinfo);
+		if (ret != ret_ok) {
+			return ret_error;
+		}
 	}
 
 	if (! cherokee_buffer_is_empty (&conn->query_string)) {
@@ -280,13 +287,14 @@ add_request (cherokee_handler_proxy_t *hdl,
 
 	/* Check the regexs
 	 */
-	replace_againt_regex_list (tmp, buf, &props->in_request_regexs);
+	re = replace_againt_regex_list (tmp, buf, &props->in_request_regexs);
+	if (re == 0) {
+		/* Did not match any regex, use the raw URL
+		 */
+		cherokee_buffer_add_buffer (buf, tmp);
+	}
 
 	TRACE(ENTRIES, "Rebuilt request: '%s'\n", tmp->buf);
-
-	/* Did not match any regex, use the raw URL
-	 */
-	cherokee_buffer_add_buffer (buf, tmp);
 	return ret_ok;
 }
 
@@ -403,8 +411,9 @@ build_request (cherokee_handler_proxy_t *hdl,
 		}
 	}
 
-	if ((is_keepalive) ||
-	    ((conn->header.version == http_version_11) && (! is_close)))
+	if ((props->in_allow_keepalive) &&
+	    ((is_keepalive) ||
+	     ((conn->header.version == http_version_11) && (! is_close))))
 	{
 		cherokee_buffer_add_str (buf, "Connection: Keep-Alive" CRLF);
 		hdl->pconn->keepalive_in = true;
@@ -508,6 +517,14 @@ build_request (cherokee_handler_proxy_t *hdl,
 	{
 		cherokee_buffer_add_str    (buf, "X-Forwarded-Host: ");
 		cherokee_buffer_add_buffer (buf, &conn->host);
+
+		if (((! conn->socket.is_tls) && (conn->bind->port != 80)) ||
+		    ((  conn->socket.is_tls) && (conn->bind->port != 443)))
+		{
+			cherokee_buffer_add_char    (buf, ':');
+			cherokee_buffer_add_ulong10 (buf, conn->bind->port);
+		}
+
 		cherokee_buffer_add_str    (buf, CRLF);
 	}
 
@@ -819,7 +836,6 @@ parse_server_header (cherokee_handler_proxy_t *hdl,
 	char                           *header_end;
 	cherokee_list_t                *i;
 	cherokee_http_version_t         version;
-	cherokee_boolean_t              encoded      = false;
 	cherokee_connection_t          *conn         = HANDLER_CONN(hdl);
 	cherokee_handler_proxy_props_t *props        = HDL_PROXY_PROPS(hdl);
 
@@ -933,12 +949,7 @@ parse_server_header (cherokee_handler_proxy_t *hdl,
 			}
 
 		} else if (strncmp (begin, "Content-Encoding:", 17) == 0) {
-			encoded = true;
-
-			if (conn->encoder != NULL) {
-				cherokee_encoder_free (conn->encoder);
-				conn->encoder = NULL;
-			}
+			BIT_SET (conn->options, conn_op_cant_encoder);
 
 		} else {
 			colon = strchr (begin, ':');
@@ -974,8 +985,11 @@ parse_server_header (cherokee_handler_proxy_t *hdl,
 	 * and the handler is configured to encode, it has to add the
 	 * encoder headers at this point.
 	 */
-	if ((! encoded) && (conn->encoder)) {
-		cherokee_encoder_add_headers (conn->encoder, buf_out);		
+	if (conn->encoder_new_func) {
+		ret = cherokee_connection_instance_encoder (conn);
+		if (ret == ret_ok) {
+			cherokee_encoder_add_headers (conn->encoder, buf_out);
+		}
 	}
 
 	/* Special case: Client uses Keepalive, the back-end sent a
