@@ -10,7 +10,7 @@ OFFSET = 15
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name = "Content Range, end"
 
         self.request           = "GET /Range100b2 HTTP/1.0\r\n" +\
